@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "widgetfloater.moc"
+#include "widgetfloater.h"
 
 // Qt
 #include <QEvent>
@@ -27,7 +27,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QWidget>
 
 // KDE
-#include <KDebug>
 #include <KDialog>
 
 // Local
